@@ -1,6 +1,6 @@
 # ABSTRACT: Get information for different currencies
 package Data::MoneyCurrency;
-$Data::MoneyCurrency::VERSION = '0.30';
+$Data::MoneyCurrency::VERSION = '0.31';
 use strict;
 use warnings;
 use utf8;
@@ -11,8 +11,6 @@ our @EXPORT_OK = qw(get_currency get_currencies_for_country);
 
 use Carp;
 use Cpanel::JSON::XS;
-use Data::Dumper;
-$Data::Dumper::Sortkeys = 1;
 use File::ShareDir qw(dist_dir);
 use Types::Serialiser;
 
@@ -69,6 +67,18 @@ sub get_currency {
         foreach my $nic (keys %$rh_non_iso){
             $rh_currency_iso->{$nic} = $rh_non_iso->{$nic};
         }
+
+        # Pre-process JSON booleans into Perl 1/0 once at load time
+        for my $currency (values %$rh_currency_iso) {
+            for my $key (keys %$currency) {
+                my $value = $currency->{$key};
+                if (   Cpanel::JSON::XS::is_bool($value)
+                    or Types::Serialiser::is_bool($value))
+                {
+                    $currency->{$key} = $value ? 1 : 0;
+                }
+            }
+        }
     }
 
     if (!$rh_currency_iso->{$currency_abbreviation}) {
@@ -77,17 +87,7 @@ sub get_currency {
 
     # Shallow copy everytime deliberately, so that the caller can mutate the
     # return value if wished, without affecting rh_currency_iso
-    my $rv = {};
-    for my $key (keys %{$rh_currency_iso->{$currency_abbreviation}}) {
-        my $value = $rh_currency_iso->{$currency_abbreviation}{$key};
-        if (   Cpanel::JSON::XS::is_bool($value)
-            or Types::Serialiser::is_bool($value))
-        {
-            $value = $value ? 1 : 0;
-        }
-        $rv->{$key} = $value;
-    }
-    return $rv;
+    return { %{$rh_currency_iso->{$currency_abbreviation}} };
 }
 
 my $rh_currencies_for_country = {
@@ -346,8 +346,8 @@ my $rh_currencies_for_country = {
 
 
 sub get_currencies_for_country {
-    croak "get_currencies_for_country received no arguments" if (scalar(@_) == 0);
-    croak "get_currencies_for_country received more than one argument" if (scalar(@_) > 1);
+    croak "get_currencies_for_country received no arguments" if @_ == 0;
+    croak "get_currencies_for_country received more than one argument" if @_ > 1;
 
     my $country = lc($_[0]);
 
@@ -373,7 +373,7 @@ Data::MoneyCurrency - Get information for different currencies
 
 =head1 VERSION
 
-version 0.30
+version 0.31
 
 =head1 SYNOPSIS
 
